
PublicMap.prototype.elForData = null;
/**
 * @class PublicMap API per l'accesso alle funzionalita' dell'embedding di
 *        Tolomeo.
 *
 * @constructor
 *
 * @param {string}
 *            destFrame - identificativo dell'IFRAME in cui e' stata inserita la mappa
 */
function PublicMap(destFrame)
{
	// Recupera il FRAME in cui e' stata inserita la mappa
	var frame = document.getElementById(destFrame);

	// Usa un oggetto A temporaneo per parsare la URI
	var l = document.createElement("a");

	l.href = frame.src;

	// Memorizza la finestra e la parte iniziale della URI per i metodi della classe
	this.contentWindow = frame.contentWindow;
	this.targetOrigin = l.protocol + "//" + l.host;
}

/**
 * Centra la mappa sulla posizione fornita come parametro, utilizzando il
 * livello di zoom spacificato.
 *
 * Opzionalmente, puo' attivare un marker nel punto indicato e fornire un
 * sistema di riferimento per le coordinate. Per default, il marker non viene
 * attivato ed il sistema di riferimento e' EPSG:3003 (Gauss Boaga fuso ovest).
 *
 * @param {Integer} coordX - coordinata X o longitudine.
 * @param {Integer} coordY - coordinata Y o latitudine.
 * @param {Integer} zoomFactor - livello di zoom definito nella mappa.
 * @param {boolean} withMarker - indica se disegnare un marker nel punto di
 *         destinazione.
 * @param {string} crsCode - codice EPSG del sitema di riferimento in cui sono
 *         le coordinate passate.
 */
PublicMap.prototype.gotoPosition = function(coordX, coordY, zoomFactor, withMarker, crsCode) {
	this.contentWindow.postMessage({
		__method:	'gotoPosition',
		coordX:		coordX,
		coordY:		coordY,
		zoomFactor:	zoomFactor,
		withMarker:	withMarker,
		crsCode:	crsCode,
	}, this.targetOrigin);
}

/**
 * Accende o spegne il layer
 *
 * @param {string}
 *            desc - descrizione del layer.
 * @param {boolean}
 *            visible - indica se il layer deve essere visibile o meno.
 */
PublicMap.prototype.setLayerVisibility = function(desc, visible) {
	this.contentWindow.postMessage({
		__method:	'setLayerVisibility',
		desc:		desc,
		visible:	visible,
	}, this.targetOrigin);
}

/**
 * Centra l'oggetto specificato
 *
 * @param {string}
 *            desc - descrizione del layer.
 * @param {string}
 *            IDTPN - identificativo dell'oggetto.
 * @param {boolean}
 *            selectIt - se true viene selezionato.
 * @param {Integer}
 *            scale - scala, se valorizzato viene fatto lo zoom alla data scala.
 * @param {Integer}
 *            buffer - buffer, se valorizzato viene fatto lo zoom aggiungendo il buffer passato.
 */
PublicMap.prototype.zoomToObj = function(desc, IDTPN, selectIt, scale, buffer) {
	this.contentWindow.postMessage({
		__method:	'zoomToObj',
		desc:		desc,
		IDTPN:		IDTPN,
		selectIt:	selectIt,
		scale:		scale,
		buffer:		buffer,
	}, this.targetOrigin);
}
/**
 * Seleziona l'oggetto specificato, effettua lo zoom
 * lo seleziona e mostra le info o dentro la mappa o nella pagina host
 * cio' dipende da parametro infoToHost passato a url mappa
 * 
 * @param desc
 * @param IDTPN
 * @param outInfo true = mostra le info nella pagina host
 * @param scale
 * @param buffer
 */
PublicMap.prototype.selectFeature = function(desc, IDTPN, zoomToObj, scale, buffer) {
	this.contentWindow.postMessage({
		__method:	'selectFeature',
		desc:		desc,
		IDTPN:		IDTPN,
		scale:		scale,
		buffer:		buffer,
	}, this.targetOrigin);
}

/**
 * Usato solo per link dalla ricerca
 *
 * @param codTPN al posto della descrizione
 * @param IDTPN
 * @param selectIt
 * @param scale
 * @param buffer
 */
PublicMap.prototype.zoomToObjWithCodTPN = function(codTPN, IDTPN, selectIt, scale, buffer) {
	this.contentWindow.postMessage({
		__method:	'zoomToObjWithCodTPN',
		codTPN:		codTPN,
		IDTPN:		IDTPN,
		selectIt:	selectIt,
		scale:		scale,
		buffer:		buffer,
	}, this.targetOrigin);
}

/**
 * Invia ricerca a mappa e riceve risposta tramite postMessage
 * 
 * @param desc
 * 		descrizione layer come da legenda
 * @param search
 * 		array ['termine da cercare nel campo 1', 'termine da cercare nel campo 2', ..., 'termine da cercare nel campo N']
 */
PublicMap.prototype.searchFeatures = function (desc, search, idsearch) {
	this.contentWindow.postMessage({
		__method:	'searchFeature',
		desc:		desc,
		search:		search,
		idsearch:   idsearch
	}, this.targetOrigin);
}

/**
 * Deseleziona tutte le features
 */
PublicMap.prototype.deselectAll = function() {
	this.contentWindow.postMessage({
		__method:	'deselectAll'
	}, this.targetOrigin);

}

/**
 * Recupera tutte le features di un layer
 */
PublicMap.prototype.getFeatures = function(layerDesc) {
	this.contentWindow.postMessage({
		__method:	'getFeatures',
		desc:		layerDesc,
	}, this.targetOrigin);
}


// Handlers && listeners *************************************************************************************************
// settaggio funzioni di utente per gestire la risposta
var __handleError = null;
PublicMap.prototype.setHandleError = function(ll) {
	__handleError = ll;
}

var __handleInfo = null;
PublicMap.prototype.setHandleInfo = function(ll) {
	__handleInfo = ll;
}

var __handleSearchEnd = null;
PublicMap.prototype.setHandleSearchEnd = function(ll) {
	__handleSearchEnd = ll;
}

var __handleSearchStart = null;
PublicMap.prototype.setHandleSearchStart = function(ll) {
	__handleSearchStart = ll;
}

var __handleNewExtent = null;
PublicMap.prototype.setHandleNewExtent = function(ll) {
	__handleNewExtent = ll;
}

// Aggiunge i listener dei custom events associati alle funzioni settate da utente in pagina host
// viene lanciata quando la mappa e' pronta (onviewrendered publicmap.html)
PublicMap.prototype.__setListenersForData = function(ed){
	if (ed != null) {
		ed.addEventListener("searchStart", __handleSearchStart, false);
		ed.addEventListener("searchResponse", __handleSearchEnd, false);
		ed.addEventListener("infoResponse", __handleInfo, false);
		ed.addEventListener("error", __handleError, false);
		ed.addEventListener("newExtent", __handleNewExtent, false);
		// setto var globale
		PublicMap.prototype.elForData = ed;
	}
}


/**
 * Listener per risposta ricerca o selezione proveniente da publicmap.html
 * arriva la risposta da postMessage di publicmap.html. Le risposte vengono inoltrate
 * tramite i custom event alla pagina host
 *
 * @param event
 */
PublicMap.prototype.__receiveMessage = function(event) {

  if (event.origin.search('publicmap').length == -1) {
	  console.log('origine non permessa');
	  return;
  }

  var data = event.data;
//  console.log(mapFrame);
  var el = PublicMap.prototype.elForData;
	  //handle response data
	  switch (data.__method) {
	    case 'searchResponse':
//	    	console.log('end search');
	    	if (typeof data.info !== 'undefined' && data.info != null && data.info.length > 0) {
	    		//custom event
	    		var event = new CustomEvent('searchResponse', { 'detail': data.info });
	    		el.dispatchEvent(event);
	    	} else {
	    		var event = new CustomEvent('searchResponse', { 'detail': null });
	    		el.dispatchEvent(event);
	    	}
	    	break;
		case 'searchStart':
//			console.log('start search...');
			var event = new CustomEvent('searchStart');
			el.dispatchEvent(event);
			break;
		case 'infoResponse':
			if (typeof data.info !== 'undefined' && data.info != null && data.info.length > 0) {
				var event = new CustomEvent('infoResponse', { 'detail': data.info });
				el.dispatchEvent(event);
			} else {
				var event = new CustomEvent('infoResponse', { 'detail': null });
	    		el.dispatchEvent(event);
			}
			break;
		case 'newExtent':
			if (typeof data.extent !== 'undefined' && data.extent != null && data.extent.length > 0) {
				var event = new CustomEvent('newExtent', { 'detail': data });
				el.dispatchEvent(event);
			} else {
				var event = new CustomEvent('newExtent', { 'detail': null });
	    		el.dispatchEvent(event);
			}
            break;
            
		case 'error':
//			console.log(data.info);
			var event = new CustomEvent('error', {'detail': data.info});
			el.dispatchEvent(event);
			break;
	    default:
            console.log("Unknown method " + data.__method);
            break;
	  }

}

window.addEventListener("message", PublicMap.prototype.__receiveMessage, false);
